translate.lang.ngram

Home | Trees | Indices | Help |
Translate Toolkit

Package translate :: Package lang :: Module ngram |
[hide private]
[frames] | no frames]

# Module ngram

source code

Classes | [hide private]
| _NGram
| NGram
| Generate

Variables | [hide private]
| nb_ngrams = `400`

Imports: re, os, glob

Home | Trees | Indices | Help |
Translate Toolkit

Generated by Epydoc 3.0.1 on Wed Mar 3 16:35:55 2010 | http://epydoc.sourceforge.net